# autolibs

Auto-import numpy as np, pandas as pd, matplotlib.pyplot as plt, and seaborn as sns.

## Installation

```bash
pip install autolibs
```

## Usage

```python
from autolibs import np, pd, plt, sns
```
